# Code of Conduct

This project follows the [Contributor Covenant v2.1](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).

We are committed to providing a welcoming and inclusive experience for everyone.

## Reporting

If you experience or witness unacceptable behavior, please report it by contacting
[@tobocop2](https://github.com/tobocop2) via GitHub.

Reports will be reviewed and investigated promptly and fairly. All community leaders are
obligated to respect the privacy and security of the reporter.

## Enforcement

Community leaders will follow the Contributor Covenant enforcement guidelines in determining
consequences for any action they deem inappropriate, threatening, offensive, or harmful.

For the full text, see <https://www.contributor-covenant.org/version/2/1/code_of_conduct/>.
